==> haskell-resource-pool-0.2.3.2-400.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resource-pool
version:              0.2.3.2
visibility:           public
id:                   resource-pool-0.2.3.2-3uIbkUYrHNdAfRBpvdjlDL
key:                  resource-pool-0.2.3.2-3uIbkUYrHNdAfRBpvdjlDL
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://github.com/bos/pool
synopsis:             A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.

category:             Data, Database, Network
abi:                  9aaae9ccc8babf4a40674c747acda15b
exposed:              True
exposed-modules:      Data.Pool
import-dirs:          /usr/lib/ghc-9.6.6/site-local/resource-pool-0.2.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/resource-pool-0.2.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resource-pool
hs-libraries:         HSresource-pool-0.2.3.2-3uIbkUYrHNdAfRBpvdjlDL
depends:
    base-4.18.2.1 hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 stm-2.5.1.0
    time-1.12.2 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock

haddock-html:         /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resource-pool-0.2.3.2-401-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resource-pool
version:              0.2.3.2
visibility:           public
id:                   resource-pool-0.2.3.2-73AdA0RAXUL5Z2VU9q4gfk
key:                  resource-pool-0.2.3.2-73AdA0RAXUL5Z2VU9q4gfk
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://github.com/bos/pool
synopsis:             A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.

category:             Data, Database, Network
abi:                  7a998fcf41934f5d3e8a07e17820e503
exposed:              True
exposed-modules:      Data.Pool
import-dirs:          /usr/lib/ghc-9.6.6/site-local/resource-pool-0.2.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/resource-pool-0.2.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resource-pool
hs-libraries:         HSresource-pool-0.2.3.2-73AdA0RAXUL5Z2VU9q4gfk
depends:
    base-4.18.2.1 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 stm-2.5.1.0
    time-1.12.2 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock

haddock-html:         /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
